summaryrefslogtreecommitdiff
path: root/guix
diff options
context:
space:
mode:
Diffstat (limited to 'guix')
-rw-r--r--guix/alexios.scm (renamed from guix/hermes.scm)4
-rw-r--r--guix/constantine.scm (renamed from guix/zeus.scm)4
-rw-r--r--guix/home.scm34
-rw-r--r--guix/system-create.scm18
4 files changed, 30 insertions, 30 deletions
diff --git a/guix/hermes.scm b/guix/alexios.scm
index e2f1a17..a6d28b1 100644
--- a/guix/hermes.scm
+++ b/guix/alexios.scm
@@ -1,11 +1,11 @@
-(define-module (hermes)
+(define-module (alexios)
#:use-module (gnu)
#:use-module (system-create))
(use-package-modules file-systems)
-(system-create #:hostname "hermes"
+(system-create #:hostname "alexios"
#:filesystem (cons* (file-system
(mount-point "/boot/efi")
(device (uuid "1F4A-0DF0"
diff --git a/guix/zeus.scm b/guix/constantine.scm
index 4b248f6..a0674bf 100644
--- a/guix/zeus.scm
+++ b/guix/constantine.scm
@@ -1,11 +1,11 @@
-(define-module (zeus)
+(define-module (constantine)
#:use-module (gnu)
#:use-module (system-create))
(use-package-modules file-systems)
-(system-create #:hostname "zeus"
+(system-create #:hostname "constantine"
#:filesystem (cons* (file-system
(mount-point "/hdd")
(device (uuid "b0fddf60-47ff-469f-b135-8f6b58812c99"
diff --git a/guix/home.scm b/guix/home.scm
index d624e67..c03e0ae 100644
--- a/guix/home.scm
+++ b/guix/home.scm
@@ -27,20 +27,23 @@
(define thanos/emacs-packages
'("emacs-next-pgtk" "emacs-nov-el" "emacs-pdf-tools" "emacs-emms"
"emacs-geiser" "emacs-geiser-guile" "emacs-notmuch" "emacs-password-store"
- "emacs-debbugs" "emacs-0x0" "emacs-emojify" "emacs-org-present" "emacs-sudo-edit"))
+ "emacs-debbugs" "emacs-0x0" "emacs-emojify" "emacs-org-present" "emacs-sudo-edit"
+ "emacs-magit"))
(define thanos/python-packages
'("python-next" "python-pip" "python-lsp-server" "python-numpy"))
(home-environment
- (packages (specifications->packages
- (append '("perl" "yt-dlp" "torbrowser" "icecat" "sbcl" "notmuch" "hunspell-dict-en"
- "gcc-toolchain" "sqlite" "hyfetch" "transmission" "isync" "mpv"
- "steam" "signal-desktop" "git" "fuzzel" "alacritty" "password-store"
- "curl" "dino" "bind" "nmap" "hunspell" "wtype" "hunspell-dict-en-med"
- "hunspell-dict-el" "mlocate" "rsync" "grimshot" "swayidle" "htop"
- "net-tools" "gnupg" "texlive" "texlive-collection-latexrecommended")
- thanos/emacs-packages thanos/python-packages thanos/fonts-packages)))
+ (packages
+ (specifications->packages
+ (append '("perl" "yt-dlp" "torbrowser" "icecat" "sbcl" "notmuch" "hunspell-dict-en"
+ "gcc-toolchain" "sqlite" "hyfetch" "transmission" "isync" "mpv"
+ "steam" "signal-desktop" "git" "fuzzel" "alacritty" "password-store"
+ "curl" "dino" "bind" "nmap" "hunspell" "wtype" "hunspell-dict-en-med"
+ "hunspell-dict-el" "mlocate" "rsync" "grimshot" "swayidle" "htop"
+ "net-tools" "gnupg" "texlive" "texlive-collection-latexrecommended"
+ "stow")
+ thanos/emacs-packages thanos/python-packages thanos/fonts-packages)))
(services
(list (service home-bash-service-type
(home-bash-configuration
@@ -50,16 +53,11 @@
("ls" . "ls --color")
("o" . "emacsclient -n")
("weather" . "curl wttr.in")
- ("gx" . "guix")))
- (bashrc (list (local-file (format #f "~a/bash-prompt.sh" thanos/dotfiles-path)
+ ("gx" . "guix")
+ ("neofetch" . "neowofetch")))
+ (bashrc
+ (list (local-file (format #f "~a/bash-prompt.sh" thanos/dotfiles-path)
#:recursive? #f)))))
- (service home-dotfiles-service-type
- (home-dotfiles-configuration
- (directories (list thanos/dotfiles-path))
- (excluded '(".*~" ".*\\.swp" "\\.git" "\\.gitignore"
- "vimium-options.json" "README" "LICENSE" ".*\\.scm" "__pycache__"
- "bash-prompt.sh"))
- (layout 'plain)))
(simple-service 'profile-service-type
home-environment-variables-service-type
'(("VISUAL" . "emacsclient")
diff --git a/guix/system-create.scm b/guix/system-create.scm
index dac64a0..6102105 100644
--- a/guix/system-create.scm
+++ b/guix/system-create.scm
@@ -26,7 +26,7 @@
'("sway" "swaylock" "swaylock-effects" "swaybg"
"waybar" "gnupg" "pinentry" "font-jetbrains-mono"
"docker" "docker-cli" "dbus" "xf86-input-libinput"
- "xf86-video-fbdev" "tailscale-bin"))
+ "xf86-video-fbdev" "tailscale-bin" "virt-manager"))
(define* (system-create #:key
(system-packages thanos/system-packages)
@@ -54,12 +54,14 @@
(comment "Thanos Apollo")
(group "users")
(home-directory "/home/thanos")
- (supplementary-groups '("wheel" "netdev" "audio" "video" "docker" "kvm")))
+ (supplementary-groups '("wheel" "netdev" "audio" "video" "docker" "kvm"
+ "libvirt")))
%base-user-accounts))
(packages
- (append (map specification->package system-packages)
- %base-packages))
+ (append
+ (map specification->package system-packages)
+ %base-packages))
(services
(append (list
@@ -79,11 +81,10 @@
(service block-facebook-hosts-service-type)
(simple-service 'add-extra-hosts
hosts-service-type
- (list (host "192.168.0.100" "zeus"
+ (list (host "192.168.0.100" "constantine"
'())
(host "192.168.0.101" "uranus"
'())))
- (service tailscale-service-type)
(service transmission-daemon-service-type
(transmission-daemon-configuration
@@ -128,8 +129,9 @@
(tlp-configuration
(cpu-boost-on-ac? #t)
(wifi-pwr-on-bat? #t))))
- ;; Services specifics for zeus
- (if (string= hostname "zeus")
+
+ ;; Services specifics for constantine
+ (if (string= hostname "constantine")
(list
(service oci-container-service-type
(list